Library for using the LSR SiFlex/ProFlex RF modules with mbed.

Revision:
6:b0445108f82f
Parent:
4:2ac0b9a7f43a
Child:
7:25e64602dc61
--- a/LsrModule.cpp	Mon Jul 25 18:03:22 2016 +0000
+++ b/LsrModule.cpp	Mon Jul 25 22:18:30 2016 +0000
@@ -753,7 +753,7 @@
 
 /**
 * Sends message type 0x44 (Channel Energy Scan) to the module via UART communication.  This will spark a response message from the module 
 * to the Arduino of type 0xC5.  Subscribing to 0xC5 in your main application will allow you to parse the response 
 * data.  See the description for SubscribeRxMsgCallback for more information.
 *
 * Example (Channel 5 for SiFLEX02, Channel 15 for ProFLEX01):
@@ -795,6 +795,19 @@
     }
 }   /*** End ChannelEnergyScanMsg ***/
 
+/**
+* Sends message type 0x51 (Query Host Interface Configuration) to the module via UART communication.  This will spark a 
+* response message from the module to the host of type 0xD1.  Subscribing to 0xD1 in your main application
+* will allow you to parse the response data.  See the description for SubscribeRxMsgCallback for more information.
+*
+*/
+void LsrModule::QueryHostInterfaceConfiguration(void)
+{
+    AddSerialMsgHeader(LSR_MODULE_QUERY_HOST_INTERFACE_CONFIGURATION, 5);
+    AddSerialMsgTrailer();
+}   /*** End QuerySupplyVoltageMsg ***/
+
+
 
 /**
 * Verifies msg type and length.
@@ -753,7 +753,7 @@
 /**
 * Sends message type 0x44 (Channel Energy Scan) to the module via UART communication.  This will spark a response message from the module 
-* to the Arduino of type 0xC5.  Subscribing to 0xC5 in your main application will allow you to parse the response 
+* to the host of type 0xC5.  Subscribing to 0xC5 in your main application will allow you to parse the response 
 * data.  See the description for SubscribeRxMsgCallback for more information.
 *